def_fixed_gamma_lambda: def

Description Usage Arguments Value

Description

Default algorithm for fitting parameters of psychometric function. Only inner parameters are fitted, gamma and lambda are fixed and have to be specified.

Usage

1
2
3
4
def_fixed_gamma_lambda(data, sigmoid, core, gamma = 0.05,
  lambda = 0.05, par = NULL, fn = NULL, gr = NULL, ...,
  method = c("Nelder-Mead", "BFGS", "CG", "L-BFGS-B", "SANN", "Brent"),
  lower = -Inf, upper = Inf, control = list(), hessian = FALSE)

Arguments

data

Specifies the data set on which the function will be fitted. Data have to be formated in specified way - data.frame/tibble (yes, no, predictor columns).

sigmoid

determines the outer shape of the fuction

core

dermines scalling of predictor

gamma

sets the loves boundary of function

lambda

sets the highes boundary of function

...

specifies the parametres of optim function

Value

vector of return values


LuchTiarna/PsyFuns documentation built on July 8, 2019, 12:28 a.m.