Description Usage Arguments Value
Estimates threshold level of given function based on given paramters.
Performance based threshold is a point where subjects performance is halfway between gamma and 1-lambda.
1 |
pf |
Psychometric function representation the threshold is to be estimated |
Level of stimuli reaching tha halfway of inner function
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.